reporust_rebootcancel

158,628 Commits over 4,566 Days - 1.45cph!

Rin
16 Days Ago
▇▇▊▉▌▅███▄ ▇▇██▆▆▍▍ ▄▆▄▊▅█ ▄▅▍█▉ ▍█▋▋▊▆▅▊▊ ▆▇ ▊▄█▇▌▉ ▌▊▅██▅▇▆ ▄ ▋ ▆▆▉ ▋▆▄▌█ ▊▊▉▌▆▅▊▇▋ ▊▊▄▅▋▉ ▉▆ ▇▇▄▉▇▇▉▉█▌█▅ █▅▉▅▍▋▆▍ ▄ █▄▌▄▇ ▋▉ ▍▊█▊▍█ ▌▋▋▍▇▆▄▆▋▆▅▆▆ █▄▌▆▍ ▇▉▆ ▌▆▆█▍▊▄▉▌█▌▅▄▇▌█▍ █▍▍▋▋▌▋ ▌▄▆█▅▇█▆ ▇▆▍█▉▉ ▇▊ ▍ ▊▌▋▇▄▆▅▅█ ▇▉█▊█▅█▉ ▉▌▇ ▉█▉▍▉▋▋▇█▌█▄▆▍▄▌▄▇▋▌▄▆▊▄▍▌▋▋▋▍▄▍▉▇█▅▇▌▋▇▉▌▋▊▌█▆▊█▇█▅▌▄▆▆▌█▍▋▍▍▉█▌▉▉▌▉▌█▅▊█▇
16 Days Ago
merge from buildingprivilege_cache
16 Days Ago
Fixed blocks registering with a 0 net id on the server when placed with the building plan
16 Days Ago
merge from misc_alloc_cleanup
16 Days Ago
Make sure to also rebuild plant info when new quality data comes in via rpc without a network update
16 Days Ago
merge from main
16 Days Ago
merge from main
16 Days Ago
clip timing updates
16 Days Ago
replaced soundpooling for a readonly struct modulator, avoids all allocs and doesn't change any of the usage
16 Days Ago
Auto adjust jobs thread count when changing CPU affinity
16 Days Ago
added dryfire wip anims, stock updates, set up animator to correctly choose correct fire and dryfire anims based on state
16 Days Ago
fixed jenkinsfile using wrong param name for slack channels
16 Days Ago
merge from sendmouseevents_optim
16 Days Ago
tattoo fixes - clamp tattoo brush size 1.0-5.0, doesnt use painting convar - zoom scaling clamp, so you cant get as far out but can also go closer than usual for fine detail - brushes now scale independent of zoom in tattooing, this does make performance a little worse, but fixes when the paint stamp doesnt cover enough of the uv and becomes spotty. WIP still - uv buffer now samples some of the uv pixels around the current target to try to smooth out and match seams where the uv resolutions dont match (like where the head meets torso etc..)
16 Days Ago
Optimized PreUpdate.SendMouseEvents by clearing the main camera event mask, nothing uses OnMouse events Saves up to 0.08ms a frame in builds
16 Days Ago
Compile fix
16 Days Ago
▊▍▊▉▋▆▊ ▆▉▉█▌█ ▌▆▆▇ ▇▌▇█▍▊█ ▆▊▅
16 Days Ago
Initial setup of different ADS and recoil settings for weapon stock being deployed/collapsed
16 Days Ago
merge from analytics_biofuel_generator
16 Days Ago
Add resource consumption/production events for the biofuel generator
16 Days Ago
pt_boat_rewrite -> turret_viewmodels
16 Days Ago
main -> pt_boat_turret_rewrite
16 Days Ago
Only send turret targets rather than every single turret movement We are effectively predicting the turret movement on the client with the server reconcilling it 1.83 -> 0.20 aim messages/s per idle turret ~46 -> ~7 B/s per turret per player On a 122 player server: roughly ~105 KB/s less outbound (~9GB a day). 6% reduction of all outbound game data
16 Days Ago
Formatting
16 Days Ago
first pass on tattoo layering - 2 layers, 1 "base" layer which is fixed onto the player model, 1 which is edited during a painting session - tattoo compositor merges the editing layer onto the base layer when exiting the menu or saving - fade is applied to base layer, and baked into the png when merging downwards - rads add fade to the base layer visually with a parameter, which is only baked in during a merge - reworked to accomodate a separate player sending the tattoo edits to the other for saving (bc tattoo chair eventually) - moved more code to serverside to allow for direct painting communication between 2 clients
16 Days Ago
Refactor and optimize LookAtIOEnt, avoid various allocs when wiring or updating battery info, avoid physics query every frame for turret interference
16 Days Ago
merge from gunfiring_optims
16 Days Ago
Fixed holding a gun searching the whole inventory every frame for reload ammo types Holding a gun with a full inventory: 0.06ms -> ~0.01ms
16 Days Ago
Initial pass, helper scene/player model guide prefab for easier balancing
Rin
16 Days Ago
merge from hackable_crate_icon
Rin
16 Days Ago
Updated hackable crate map icon
16 Days Ago
Merge from vcc
16 Days Ago
merge from gunfiring_optims
16 Days Ago
Fixed issues from the far shot and shell replay changes
16 Days Ago
Wallpaper health was included with every building block, even those without wallpaper Saves 10 B per building block
16 Days Ago
More prefab fixes
16 Days Ago
Optimize LookAtPlant and LookAtPlanter, only rebuild if data changed
16 Days Ago
Stop muzzle flash light casting any shadows past 60 meters cause it's wasteful Added MaxShadowDistance to LightLOD, default 0 so existing lights aren't changed
16 Days Ago
Fix head jitter when playing turn in place anims
16 Days Ago
Pack the tree billboard lists sent to joining players Each cell now sends its prefabs once, ids as deltas from the previous tree and positions as raw halves instead of a nested message per tree ~30 -> ~16 bytes per tree, roughly 1.8 MB -> 0.9 MB per player join on a full map
16 Days Ago
▍ ▄▍▉▆▌ ▌██▉ ▊▌▍▉▇▉▋█▌▍▉▄▄▅▌▇█▄▌▍▌▇
16 Days Ago
▋ ▆▋▇▉▊▅█ ▊▇▆▆▋█▅▋▆ ▊▊▉ ▋▊▄▄▇▉▆▆ ▅▄ ▊▌▍▋ ▍▇ ▉▉█▇▄▅▆▉ ▌▅▄▇█ ▇▋▄ ▍▉▇ ▅▆▋▄▄▇▌▇▉ ▋█▆▄▉▌▆▊▆▆▉ ▊█▉▅▆▉ ▌▌▋▇ ▉ ▌▇▇ ▋▄▋▉▇▄
16 Days Ago
Reviewed the 3P gun effects we spawn for distant shots: - Muzzle particles don't emit past 60m anymore, you only get the muzzle light and the sound - Shells aren't spawned past 15m Unchanged when using scopes and binoculars, the distances are stretched based on zoom scale
16 Days Ago
Item icon, delete some unused uzi fbx files at the root of the assets folder
16 Days Ago
merge from snowmobile_wheel_fix
16 Days Ago
Fixed snowmobile wheels jittering at standstill due to physics noise Before: https://files.facepunch.com/raul/2026/October/13_14-12-FrailCobra.mp4 After: https://files.facepunch.com/raul/2026/October/13_14-14-RedBlacknorwegianelkhound.mp4
16 Days Ago
Texture fixes
16 Days Ago
Send animal look direction in an RPC rather than with SendNetworkUpdate Animals with look animators were running network updates crazy often rather than just sending the look over This was especially bad with cows, wolfs, sheep and bulls Worst offender is cow at ~144 bytes per look update (network update). ~350 B/s per cow per player -> ~60 B/s
16 Days Ago
merge from main
16 Days Ago
Set all the gun firing effects warmed up amount accordingly Estimated +21MB vs main, still around -29MB overall after removing the 3900 useless thrown projectiles